@@ -1,6 +1,7 @@
 package WebService::Braintree::ApplePayCard::CardType;
-$WebService::Braintree::ApplePayCard::CardType::VERSION = '0.93';
-use strict;
+$WebService::Braintree::ApplePayCard::CardType::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
 use constant AmericanExpress => "Apple Pay - American Express";
 use constant MasterCard => "Apple Pay - MasterCard";
@@ -13,3 +14,4 @@ use constant All => [
 ];
 
 1;
+__END__
