@@ -1,5 +1,8 @@
 package WebService::Braintree::CreditCardGateway;
-$WebService::Braintree::CreditCardGateway::VERSION = '0.93';
+$WebService::Braintree::CreditCardGateway::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 with 'WebService::Braintree::Role::MakeRequest';
 
@@ -46,5 +49,6 @@ sub from_nonce {
 }
 
 __PACKAGE__->meta->make_immutable;
-1;
 
+1;
+__END__
