@@ -1,13 +1,15 @@
 package WebService::Braintree::CustomerGateway;
-$WebService::Braintree::CustomerGateway::VERSION = '0.93';
+$WebService::Braintree::CustomerGateway::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 with 'WebService::Braintree::Role::MakeRequest';
 
 use Carp qw(confess);
 use WebService::Braintree::Validations qw(verify_params customer_signature);
-use WebService::Braintree::Util qw(validate_id);
+use WebService::Braintree::Util qw(to_instance_array validate_id);
 use WebService::Braintree::Result;
-use WebService::Braintree::Util;
 
 has 'gateway' => (is => 'ro');
 
@@ -40,16 +42,18 @@ sub search {
     my $params = $block->($search)->to_hash;
     my $response = $self->gateway->http->post("/customers/advanced_search_ids", {search => $params});
     return WebService::Braintree::ResourceCollection->new()->init($response, sub {
-                                                                      $self->fetch_customers($search, shift);
-                                                                  });
+        $self->fetch_customers($search, shift);
+    });
 }
 
 sub all {
     my $self = shift;
     my $response = $self->gateway->http->post("/customers/advanced_search_ids");
     return WebService::Braintree::ResourceCollection->new()->init($response, sub {
-                                                                      $self->fetch_customers(WebService::Braintree::CustomerSearch->new, shift);
-                                                                  });
+        $self->fetch_customers(
+            WebService::Braintree::CustomerSearch->new, shift,
+        );
+    });
 }
 
 sub fetch_customers {
@@ -62,8 +66,7 @@ sub fetch_customers {
     return to_instance_array($attrs, "WebService::Braintree::Customer");
 }
 
-
 __PACKAGE__->meta->make_immutable;
+
 1;
-
-
+__END__
