@@ -1,5 +1,8 @@
 package WebService::Braintree::CustomerSearch;
-$WebService::Braintree::CustomerSearch::VERSION = '0.93';
+$WebService::Braintree::CustomerSearch::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 use WebService::Braintree::AdvancedSearch;
 
@@ -35,6 +38,6 @@ sub to_hash {
 }
 
 __PACKAGE__->meta->make_immutable;
+
 1;
-
-
+__END__
