@@ -1,6 +1,7 @@
 package WebService::Braintree::ErrorCodes::AuthorizationFingerprint;
-$WebService::Braintree::ErrorCodes::AuthorizationFingerprint::VERSION = '0.93';
-use strict;
+$WebService::Braintree::ErrorCodes::AuthorizationFingerprint::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
 use constant InvalidCreatedAt                  => "93204";
 use constant InvalidFormat                     => "93202";
@@ -11,3 +12,4 @@ use constant OptionsNotAllowedWithoutCustomer  => "93207";
 use constant SignatureRevoked                  => "93203";
 
 1;
+__END__
