@@ -1,9 +1,11 @@
 package WebService::Braintree::ErrorCodes::CreditCard::Options;
-$WebService::Braintree::ErrorCodes::CreditCard::Options::VERSION = '0.93';
-use strict;
+$WebService::Braintree::ErrorCodes::CreditCard::Options::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
 use constant UpdateExistingTokenIsInvalid           => "91723";
 use constant UseBillingForShippingDisabled          => "91572";
 use constant VerificationMerchantAccountIdIsInvalid => "91728";
 
 1;
+__END__
