@@ -1,9 +1,11 @@
 package WebService::Braintree::ErrorCodes::MerchantAccount::Business::Address;
-$WebService::Braintree::ErrorCodes::MerchantAccount::Business::Address::VERSION = '0.93';
-use strict;
+$WebService::Braintree::ErrorCodes::MerchantAccount::Business::Address::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
 use constant RegionIsInvalid        => "82684";
 use constant StreetAddressIsInvalid => "82685";
 use constant PostalCodeIsInvalid    => "82686";
 
 1;
+__END__
