@@ -1,6 +1,7 @@
 package WebService::Braintree::ErrorCodes::MerchantAccount::Individual;
-$WebService::Braintree::ErrorCodes::MerchantAccount::Individual::VERSION = '0.93';
-use strict;
+$WebService::Braintree::ErrorCodes::MerchantAccount::Individual::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
 use constant FirstNameIsRequired    => "82637";
 use constant LastNameIsRequired     => "82638";
@@ -14,3 +15,4 @@ use constant DateOfBirthIsInvalid   => "82666";
 use constant EmailIsRequired        => "82667";
 
 1;
+__END__
