@@ -1,9 +1,11 @@
 package WebService::Braintree::ErrorCodes::SettlementBatchSummary;
-$WebService::Braintree::ErrorCodes::SettlementBatchSummary::VERSION = '0.93';
-use strict;
+$WebService::Braintree::ErrorCodes::SettlementBatchSummary::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
 use constant CustomFieldIsInvalid     => "82303";
 use constant SettlementDateIsInvalid  => "82302";
 use constant SettlementDateIsRequired => "82301";
 
 1;
+__END__
