@@ -1,5 +1,7 @@
 package WebService::Braintree::MerchantAccount::FundingDetails;
-$WebService::Braintree::MerchantAccount::FundingDetails::VERSION = '0.93';
+$WebService::Braintree::MerchantAccount::FundingDetails::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
 use Moose;
 extends "WebService::Braintree::ResultObject";
@@ -10,5 +12,6 @@ sub BUILD {
 }
 
 __PACKAGE__->meta->make_immutable;
-1;
 
+1;
+__END__
