@@ -1,5 +1,8 @@
 package WebService::Braintree::Nonce;
-$WebService::Braintree::Nonce::VERSION = '0.93';
+$WebService::Braintree::Nonce::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 extends 'WebService::Braintree::ResultObject';
 
@@ -10,6 +13,7 @@ sub BUILD {
     $self->set_attributes_from_hash($self, $attributes);
 }
 
-
 __PACKAGE__->meta->make_immutable;
+
 1;
+__END__
