@@ -1,5 +1,8 @@
 package WebService::Braintree::PayPalAccountGateway;
-$WebService::Braintree::PayPalAccountGateway::VERSION = '0.93';
+$WebService::Braintree::PayPalAccountGateway::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 with 'WebService::Braintree::Role::MakeRequest';
 
@@ -23,5 +26,6 @@ sub update {
 }
 
 __PACKAGE__->meta->make_immutable;
-1;
 
+1;
+__END__
