@@ -1,5 +1,8 @@
 package WebService::Braintree::PaymentMethodGateway;
-$WebService::Braintree::PaymentMethodGateway::VERSION = '0.93';
+$WebService::Braintree::PaymentMethodGateway::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 with 'WebService::Braintree::Role::MakeRequest';
 
@@ -7,6 +10,8 @@ use Carp qw(confess);
 
 has 'gateway' => (is => 'ro');
 
+use WebService::Braintree::Util qw(validate_id);
+
 sub create {
     my ($self, $params) = @_;
     $self->_make_request("/payment_methods", 'post', {payment_method => $params});
@@ -24,7 +29,7 @@ sub delete {
 
 sub find {
     my ($self, $token) = @_;
-    if (!defined($token) || WebService::Braintree::Util::trim($token) eq "") {
+    if (!validate_id($token)) {
         confess "NotFoundError";
     }
 
@@ -32,7 +37,8 @@ sub find {
     return $response->payment_method;
 }
 
-
 __PACKAGE__->meta->make_immutable;
+
 1;
+__END__
 
