@@ -1,13 +1,18 @@
 package WebService::Braintree::PaymentMethodNonceGateway;
-$WebService::Braintree::PaymentMethodNonceGateway::VERSION = '0.93';
+$WebService::Braintree::PaymentMethodNonceGateway::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 with 'WebService::Braintree::Role::MakeRequest';
 
+use WebService::Braintree::Util qw(validate_id);
+
 has 'gateway' => (is => 'ro');
 
 sub create {
     my ($self, $token) = @_;
-    if (!defined($token) || WebService::Braintree::Util::trim($token) eq "") {
+    if (!validate_id($token)) {
         confess "NotFoundError";
     }
     my $response = $self->_make_request("/payment_methods/${token}/nonces", 'post');
@@ -16,7 +21,7 @@ sub create {
 
 sub find {
     my ($self, $token) = @_;
-    if (!defined($token) || WebService::Braintree::Util::trim($token) eq "") {
+    if (!validate_id($token)) {
         confess "NotFoundError";
     }
 
@@ -24,7 +29,7 @@ sub find {
     return $response;
 }
 
-
 __PACKAGE__->meta->make_immutable;
-1;
 
+1;
+__END__
