@@ -1,5 +1,8 @@
 package WebService::Braintree::SettlementBatchSummaryGateway;
-$WebService::Braintree::SettlementBatchSummaryGateway::VERSION = '0.93';
+$WebService::Braintree::SettlementBatchSummaryGateway::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 with 'WebService::Braintree::Role::MakeRequest';
 use Carp qw(confess);
@@ -17,5 +20,6 @@ sub generate {
 }
 
 __PACKAGE__->meta->make_immutable;
-1;
 
+1;
+__END__
