@@ -1,5 +1,8 @@
 package WebService::Braintree::SubscriptionSearch;
-$WebService::Braintree::SubscriptionSearch::VERSION = '0.93';
+$WebService::Braintree::SubscriptionSearch::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
+
 use Moose;
 use WebService::Braintree::AdvancedSearch;
 
@@ -24,5 +27,6 @@ sub to_hash {
 }
 
 __PACKAGE__->meta->make_immutable;
-1;
 
+1;
+__END__
