@@ -1,12 +1,26 @@
 package WebService::Braintree::Validations;
-$WebService::Braintree::Validations::VERSION = '0.93';
-use strict;
+$WebService::Braintree::Validations::VERSION = '0.94';
+use 5.010_001;
+use strictures 1;
 
-use WebService::Braintree::Util;
-use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
+use WebService::Braintree::Util qw(is_hashref);
+
+use vars qw(@ISA @EXPORT_OK);
 use Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(verify_params address_signature client_token_signature_with_customer_id client_token_signature_without_customer_id credit_card_signature customer_signature transaction_signature clone_transaction_signature merchant_account_signature transaction_search_results_signature);
+
+our @EXPORT_OK = qw(
+    verify_params
+    address_signature
+    client_token_signature_with_customer_id
+    client_token_signature_without_customer_id
+    credit_card_signature
+    customer_signature
+    transaction_signature
+    clone_transaction_signature
+    merchant_account_signature
+    transaction_search_results_signature
+);
 
 sub verify_params {
     my ($params, $white_list) = @_;
@@ -135,3 +149,4 @@ sub transaction_signature{
 }
 
 1;
+__END__
